#!/bin/bash -e
Current_DIR=$(cd `dirname $0`; pwd)
registry=""
backupDir=""
restoreTime="now"
command=$1
while [ -n $2 ]
do
    case $2 in 
        --path) backupDir=$3; shift 2;;
        --registry) registry=$3; shift 2;;
        --time) restoreTime=$3; shift 2;;
        *) break ;;
    esac
done
if [ -z $backupDir ];then
  mkdir -p $Current_DIR/backup
  backupDir=$Current_DIR/backup
fi

volumerize::init(){
  docker run -d \
    --name imanager-volumerize \
    -v /var/run/docker.sock:/var/run/docker.sock \
    -v imanager_composeui-volume:/source/imanager_composeui-volume:ro \
    -v imanager_consul-data-volume:/source/imanager_consul-data-volume:ro \
    -v imanager_esdata-volume:/source/imanager_esdata-volume:ro \
    -v imanager_grafana-data-volume:/source/imanager_grafana-data-volume:ro \
    -v imanager_imgr-config-volume:/source/imanager_imgr-config-volume:ro \
    -v imanager_imgr-mysql-volume:/source/imanager_imgr-mysql-volume:ro \
    -v imanager_nginx-volume:/source/imanager_nginx-volume:ro \
    -v imanager_prometheus-data-volume:/source/imanager_prometheus-data-volume:ro \
    -v imanager_zabbix-mysql-volume:/source/imanager_zabbix-mysql-volume:ro \
    -v $backupDir:/backup \
    -v cache_volume:/volumerize-cache \
    -e "TZ=Asia/Shanghai" \
    -e "VOLUMERIZE_CONTAINERS=imanager-nginx   imanager_grafana_1  imanager_phpmyadmin_1  imanager_zabbix-java-gateway_1 imanager_mysqldb_1   imanager_elastic_1  imanager_mailserver_1  imanager_composeui_1 imanager_consul_1  imanager_mysql-server_1   imanager_imanager-ui_1  imanager_prometheus_1 imanager_kibana_1 imanager-zabbix-proxy  imanager_zabbix-server_1 imanager_zabbix-web-nginx-mysql_1 imanager" \
    -e "VOLUMERIZE_SOURCE=/source" \
    -e "VOLUMERIZE_TARGET=file:///backup" \
    $registry"supermap/volumerize:1.5.0"
}
volumerize::backup(){
  volumerize::init
  docker exec imanager-volumerize backupFull
  echo "Back up imanager success!Backup directory is "$backupDir
  docker rm -f imanager-volumerize
  docker volume rm cache_volume
}

volumerize::restore(){
  docker run --rm \
    -v /var/run/docker.sock:/var/run/docker.sock \
    -v imanager_composeui-volume:/source/imanager_composeui-volume \
    -v imanager_consul-data-volume:/source/imanager_consul-data-volume \
    -v imanager_esdata-volume:/source/imanager_esdata-volume \
    -v imanager_grafana-data-volume:/source/imanager_grafana-data-volume \
    -v imanager_imgr-config-volume:/source/imanager_imgr-config-volume \
    -v imanager_imgr-mysql-volume:/source/imanager_imgr-mysql-volume \
    -v imanager_nginx-volume:/source/imanager_nginx-volume \
    -v imanager_prometheus-data-volume:/source/imanager_prometheus-data-volume \
    -v imanager_zabbix-mysql-volume:/source/imanager_zabbix-mysql-volume \
    -v $backupDir:/backup:ro \
    -v cache_volume:/volumerize-cache \
    -e "TZ=Asia/Shanghai" \
    -e "VOLUMERIZE_SOURCE=/source" \
    -e "VOLUMERIZE_TARGET=file:///backup" \
    -e "VOLUMERIZE_CONTAINERS=imanager-nginx imanager_grafana_1 imanager_phpmyadmin_1 imanager_zabbix-java-gateway_1 imanager_mysqldb_1 imanager_elastic_1 imanager_mailserver_1 imanager_composeui_1 imanager_consul_1 imanager_mysql-server_1 imanager_imanager-ui_1 imanager_prometheus_1 imanager_kibana_1 imanager-zabbix-proxy  imanager_zabbix-server_1 imanager_zabbix-web-nginx-mysql_1 imanager" \
    $registry"supermap/volumerize:1.5.0" restore -t $restoreTime
  echo "Restore imanager success!"
}

volumerize::list(){
  volumerize::init
  docker exec imanager-volumerize list
  docker rm -f imanager-volumerize
  docker volume rm cache_volume
}

main(){
  case $command in
  "backup")
    volumerize::backup
    ;;
  "restore")
    volumerize::restore
    ;;
  "list")
    volumerize::list
    ;;
  *)
    echo "usage: $0 COMMAND"
    echo "Commands:"
    echo "  backup    Back up imanager data"
    echo "  list      List available backup"
    echo "  restore   Restore imanager data"
    echo "Options:"
    echo "  --registry string  Specify image registry"
    echo "  --path string      Specify backup data directory"
    ;;
  esac
}

main $@
